survexpMC: Exponential survival analysis with MCMC
Description
Survival analysis with exponential distribution by MCMC
Usage
survexpMC(m1, n1, m2, n2, chains, iter, data)
Value
survexpMCout A data set listing estimated posterior means and deviances
Arguments
m1
Starting column number from where variables of high dimensional data will be selected.
n1
Ending column number till where variables of high dimensional data will get selected.
m2
Starting column number from where demographic observations starts
n2
Ending column number of the demographic observations
chains
Number of MCMC chains
iter
Number of MCMC iterations
data
High dimensional data having survival duration as (OS), event information as Death (1 if died, or 0 if alive).
Author
Atanu Bhattacharjee and Akash Pawar
References
Kumar, M., Sonker, P. K., Saroj, A., Jain, A., Bhattacharjee, A.,
& Saroj, R. K. (2020). Parametric survival analysis using R: Illustration
with lung cancer data. Cancer Reports, 3(4), e1210.