Learn R Programming

SurviMChd (version 0.1.2)

survweibMC: Weibull survival analysis with MCMC

Description

Survival analysis with weibull distribution by MCMC

Usage

survweibMC(m1, n1, m2, n2, chains, iter, data)

Value

beta1[1] Posterior estimates of regression coefficients and deviance

Arguments

m1

Starting column number from where variables of high dimensional data will be selected.

n1

Ending column number till where variables of high dimensional data will get selected.

m2

Starting column number from where demographic observations starts

n2

Ending column number of the demographic observations

chains

Number of MCMC chains

iter

Number of MCMC iterations

data

High dimensional data having survival duration as (OS), event information as Death (1 if died, or 0 if alive).

Author

Atanu Bhattacharjee and Akash Pawar

References

Kumar, M., Sonker, P. K., Saroj, A., Jain, A., Bhattacharjee, A., & Saroj, R. K. (2020). Parametric survival analysis using R: Illustration with lung cancer data. Cancer Reports, 3(4), e1210.

Khan, S. A. (2018). Exponentiated Weibull regression for time-to-event data. Lifetime data analysis, 24(2), 328-354.

See Also

survexpMC

Examples

Run this code
# \donttest{
##
data(headnneck)
survweibMC(m1=8,n1=12,m2=4,n2=7,chains=2,iter=10,data=headnneck)
##
# }

Run the code above in your browser using DataLab