frairand: Frailty with random effects in high dimensional data with MCMC
Description
Random effects frailty model
Usage
frairand(m, n, Ins, Del, Time, T.min, chn, iter, adapt, data)
Value
frairandout
omeg[i] are frailty effects.
Arguments
m
Starting column number form where study variables to be selected.
n
Ending column number till where study variables will get selected.
Ins
Variable name of Institute information.
Del
Variable name containing the event information.
Time
Variable name containing the time information.
T.min
Variable name containing the time of event information.
chn
Numner of MCMC chains.
iter
Define number of iterations as number.
adapt
Define number of adaptations as number.
data
High dimensional data having survival duration, event information and column of time for death cases.
Author
Atanu Bhattacharjee and Akash Pawar
Details
By given m and n, a total of 3 variables can be selected.
References
Tawiah, R., Yau, K. K., McLachlan, G. J., Chambers, S. K., &
Ng, S. K. (2019). Multilevel model with random effects for clustered survival
data with multiple failure outcomes. Statistics in medicine, 38(6), 1036-1055.